Learn R Programming

geouy (version 0.2.6)

is.uy32721: This function test if an 'sf' object match with Uruguay at crs = 32721.

Description

This function test if an 'sf' object match with Uruguay at crs = 32721.

Usage

is.uy32721(x)

Value

logical value based in crs parameter of the sf object

Arguments

x

An 'sf' object with the same crs as the homonym parameter

See Also

Other crs: is.uy4326(), is.uy5381(), is.uy5382()

Examples

Run this code
# \donttest{
is.uy32721(load_geouy("Peajes"))
# }

Run the code above in your browser using DataLab