Learn R Programming

geouy (version 0.2.6)

where_uy: This function return an 'sf' object with the geometry of the consult id or group of ids, of an administrative units in Uruguay.

Description

This function return an 'sf' object with the geometry of the consult id or group of ids, of an administrative units in Uruguay.

Usage

where_uy(c = "Localidades pg", d = "cod", e, crs = 32721)

Value

sf object with the geometries of the d ids

Arguments

c

Define the geometries to consult: may be: "Departamentos", "Secciones", "Zonas", etc. View(metadata) for details.

d

A vector who determines the variables to be consult, with two options: "cod" or "name". Default "cod".

e

A vector who determines the ids or names to identify.

crs

Define the Coordinate Reference Systems you want the output, default 32721

See Also

Other service: add_geom(), geocode_ide_uy(), load_geouy(), reverse_ide_uy(), tiles_geouy(), which_uy()

Examples

Run this code
# \donttest{
x <- where_uy(c = "Localidades pg", d = "cod", e = c(1120, 2220))
# }

Run the code above in your browser using DataLab