Learn R Programming

geouy (version 0.2.6)

add_geom: This function allows you to add a geom variable with a code variable of "zona", "barrio", "localidad", "segmentos", "secciones" or "departamentos".

Description

This function allows you to add a geom variable with a code variable of "zona", "barrio", "localidad", "segmentos", "secciones" or "departamentos".

Usage

add_geom(data, unit, variable, crs = 32721)

Value

data.frame

Arguments

data

data.frame

unit

spatial unit of data, may be: "Departamentos", "Secciones", "Secc MVD 2004", "Segmentos", "Segm MVD 2004", "Segm URB INT 2004", "Zonas", "Zonas MVD 2004", "Zonas URB INT 2004", "Localidades pg", "Municipios" o "Barrios".

variable

Variable name of unit code (without duplicates)

crs

Coordinates Refence Sistem, usually in region 32721 or 4326 (default 32721)

Details

Disclaimer: This script is not an official INE product. Aviso: El script no es un producto oficial de INE.

See Also

Other service: geocode_ide_uy(), load_geouy(), reverse_ide_uy(), tiles_geouy(), where_uy(), which_uy()

Examples

Run this code
# \donttest{
pobre_x_dpto <- as.data.frame(cbind(nomdpto = c("ARTIGAS", "DURAZNO", "FLORIDA", "LAVALLEJA"),
               Pobreza = c(0.26, 0.27, 0.07, 0.10)))
pobre_x_dpto_geo <- add_geom(data = pobre_x_dpto, unit = "Deptos", variable = "nomdpto")
# }

Run the code above in your browser using DataLab