Learn R Programming

geouy (version 0.2.6)

is.uy4326: This function test if an 'sf' object match with Uruguay at crs = 4326.

Description

This function test if an 'sf' object match with Uruguay at crs = 4326.

Usage

is.uy4326(x)

Value

logical value based in crs parameter of the sf object

Arguments

x

An 'sf' object with the same crs as the homonym parameter

See Also

Other crs: is.uy32721(), is.uy5381(), is.uy5382()

Examples

Run this code
# \donttest{
is.uy4326(load_geouy("Peajes"))
# }

Run the code above in your browser using DataLab