powered by
This function test if an 'sf' object match with Uruguay at crs = 5381.
is.uy5381(x)
logical value based in crs parameter of the sf object
An 'sf' object with the same crs as the homonym parameter
Other crs: is.uy32721(), is.uy4326(), is.uy5382()
is.uy32721()
is.uy4326()
is.uy5382()
# \donttest{ is.uy5381(load_geouy("CCZ")) # }
Run the code above in your browser using DataLab