Learn R Programming

geouy (version 0.2.6)

load_geouy: This function allows to take oficial uruguayan geometries, as object "sf", from various servers.

Description

This function allows to take oficial uruguayan geometries, as object "sf", from various servers.

Usage

load_geouy(c, crs = 32721, folder = tempdir())

Value

sf object with the requested geometries

Arguments

c

Define the geometries to download: may be: "Departamentos", "Secciones", "Zonas", etc. View(metadata) for details.

crs

Define the Coordinate Reference Systems you want the output, default 32721

folder

Folder where are the files download if formato == "zip" in metadata. Default tempdir()

See Also

Other service: add_geom(), geocode_ide_uy(), reverse_ide_uy(), tiles_geouy(), where_uy(), which_uy()

Examples

Run this code
# \donttest{
secc <- load_geouy(c = "Secciones")
# }

Run the code above in your browser using DataLab