powered by
This function allows to take oficial uruguayan geometries, as object "sf", from various servers.
load_geouy(c, crs = 32721, folder = tempdir())
sf object with the requested geometries
Define the geometries to download: may be: "Departamentos", "Secciones", "Zonas", etc. View(metadata) for details.
Define the Coordinate Reference Systems you want the output, default 32721
Folder where are the files download if formato == "zip" in metadata. Default tempdir()
Other service: add_geom(), geocode_ide_uy(), reverse_ide_uy(), tiles_geouy(), where_uy(), which_uy()
add_geom()
geocode_ide_uy()
reverse_ide_uy()
tiles_geouy()
where_uy()
which_uy()
# \donttest{ secc <- load_geouy(c = "Secciones") # }
Run the code above in your browser using DataLab