tiles_geouy: This function allows to Download .jpg or .tif files from the IDEuy tiles repository, according to a 'sf' object bbox.
Description
This function allows to Download .jpg or .tif files from the IDEuy tiles repository, according to a 'sf' object bbox.
Usage
tiles_geouy(x, d = NA, format = "rgb", folder = tempdir(), urban = FALSE)
Value
raster::stack object with th cropped tif corresponding to x bbox
Arguments
x
An 'sf' object with the same crs as the homonym parameter
d
numeric; buffer distance for all, or for each of the elements in x; in case dist is a units object, it should be convertible to arc_degree if x has geographic coordinates, and to st_crs(x)$units otherwise. Default NA, but if x is a only one point buffer default is 100.
format
Format of the archives to download (avaiable: "rgb" and "rgbi") Default "rgb"
folder
Folder where are the files or be download
urban
logical; If FALSE take orthophotos of national flight with 32cm per pixel, if TRUE take urban flight with 10cm per pixel (avaible only Montevideo at the moment)
See Also
Other service:
add_geom(),
geocode_ide_uy(),
load_geouy(),
reverse_ide_uy(),
where_uy(),
which_uy()