powered by
This function return an 'sf' object with the geometry of the consult id or group of ids, of an administrative units in Uruguay.
where_uy(c = "Localidades pg", d = "cod", e, crs = 32721)
sf object with the geometries of the d ids
Define the geometries to consult: may be: "Departamentos", "Secciones", "Zonas", etc. View(metadata) for details.
A vector who determines the variables to be consult, with two options: "cod" or "name". Default "cod".
A vector who determines the ids or names to identify.
Define the Coordinate Reference Systems you want the output, default 32721
Other service: add_geom(), geocode_ide_uy(), load_geouy(), reverse_ide_uy(), tiles_geouy(), which_uy()
add_geom()
geocode_ide_uy()
load_geouy()
reverse_ide_uy()
tiles_geouy()
which_uy()
# \donttest{ x <- where_uy(c = "Localidades pg", d = "cod", e = c(1120, 2220)) # }
Run the code above in your browser using DataLab