which_uy: This function allows to add to an 'sf' object its spatial coincidence with one or more administrative units in Uruguay, generating the corresponding variables.
Description
This function allows to add to an 'sf' object its spatial coincidence with one or more administrative units in Uruguay, generating the corresponding variables.
Usage
which_uy(x, c = c("Localidades pg", "Departamentos"), d = c("cod", "name"))
Value
sf object with the x geometries, with d variables requested from c added
Arguments
x
An 'sf' object with the same crs as the homonym parameter
c
Define the geometries to download: may be: "Departamentos", "Secciones", "Zonas", etc. View(metadata) for details.
d
A vector who determines the variables to be added, with three options: "cod", "name", or "full". Default c("cod", "name").
See Also
Other service:
add_geom(),
geocode_ide_uy(),
load_geouy(),
reverse_ide_uy(),
tiles_geouy(),
where_uy()